@@ -72,6 +72,7 @@ class Collection(object):
         self._driver = None
         self._schema = None
         self._crs = None
+        self._crs_wkt = None
         self.env = None
         
         self.path = vsi_path(path, vsi, archive)
@@ -186,6 +187,13 @@ class Collection(object):
             self._crs = self.session.get_crs()
         return self._crs
 
+    @property
+    def crs_wkt(self):
+        """Returns a WKT string."""
+        if self._crs_wkt is None and self.mode in ("a", "r") and self.session:
+            self._crs_wkt = self.session.get_crs_wkt()
+        return self._crs_wkt
+
     @property
     def meta(self):
         """Returns a mapping with the driver, schema, and crs properties."""
